@@ -1,27 +1,34 @@
+# -*- coding: utf-8 -*-
 import os
-import py
-import sys
-import pytest
-import execnet
 import subprocess
-from execnet.gateway_io import ssh_args, popen_args, vagrant_ssh_args
+import sys
+
+import execnet
+import py
+import pytest
+from execnet.gateway_io import popen_args
+from execnet.gateway_io import ssh_args
+from execnet.gateway_io import vagrant_ssh_args
 
 XSpec = execnet.XSpec
 
 
-skip_win_pypy = pytest.mark.xfail(condition=hasattr(sys, 'pypy_version_info') and sys.platform.startswith('win'),
-                                  reason='failing on Windows on PyPy (#63)')
+skip_win_pypy = pytest.mark.xfail(
+    condition=hasattr(sys, "pypy_version_info") and sys.platform.startswith("win"),
+    reason="failing on Windows on PyPy (#63)",
+)
 
 
 class TestXSpec:
     def test_norm_attributes(self):
-        spec = XSpec(r"socket=192.168.102.2:8888//python=c:/this/python2.5"
-                     r"//chdir=d:\hello")
+        spec = XSpec(
+            r"socket=192.168.102.2:8888//python=c:/this/python2.5" r"//chdir=d:\hello"
+        )
         assert spec.socket == "192.168.102.2:8888"
         assert spec.python == "c:/this/python2.5"
         assert spec.chdir == r"d:\hello"
         assert spec.nice is None
-        assert not hasattr(spec, '_xyz')
+        assert not hasattr(spec, "_xyz")
 
         with pytest.raises(AttributeError):
             spec._hello()
@@ -32,8 +39,7 @@ class TestXSpec:
         assert spec.chdir is None
         assert spec.nice == "3"
 
-        spec = XSpec("ssh=user@host"
-                     "//chdir=/hello/this//python=/usr/bin/python2.5")
+        spec = XSpec("ssh=user@host" "//chdir=/hello/this//python=/usr/bin/python2.5")
         assert spec.ssh == "user@host"
         assert spec.python == "/usr/bin/python2.5"
         assert spec.chdir == "/hello/this"
@@ -48,9 +54,9 @@ class TestXSpec:
 
         spec = XSpec(
             "ssh=-i ~/.ssh/id_rsa-passwordless_login -p 22100 user@host"
-            "//python=python3")
-        assert spec.ssh == \
-            "-i ~/.ssh/id_rsa-passwordless_login -p 22100 user@host"
+            "//python=python3"
+        )
+        assert spec.ssh == "-i ~/.ssh/id_rsa-passwordless_login -p 22100 user@host"
         assert spec.python == "python3"
 
     def test_execmodel(self):
@@ -62,24 +68,25 @@ class TestXSpec:
     def test_ssh_options_and_config(self):
         spec = XSpec("ssh=-p 22100 user@host//python=python3")
         spec.ssh_config = "/home/user/ssh_config"
-        assert ssh_args(spec)[:6] == [
-            "ssh", "-C", "-F", spec.ssh_config, "-p", "22100"]
+        assert ssh_args(spec)[:6] == ["ssh", "-C", "-F", spec.ssh_config, "-p", "22100"]
 
     def test_vagrant_options(self):
         spec = XSpec("vagrant_ssh=default//python=python3")
-        assert vagrant_ssh_args(spec)[:-1] == [
-            'vagrant', 'ssh', 'default', '--', '-C']
+        assert vagrant_ssh_args(spec)[:-1] == ["vagrant", "ssh", "default", "--", "-C"]
 
     def test_popen_with_sudo_python(self):
         spec = XSpec("popen//python=sudo python3")
         assert popen_args(spec) == [
-            'sudo', 'python3', '-u', '-c',
-            'import sys;exec(eval(sys.stdin.readline()))'
+            "sudo",
+            "python3",
+            "-u",
+            "-c",
+            "import sys;exec(eval(sys.stdin.readline()))",
         ]
 
     def test_env(self):
         xspec = XSpec("popen//env:NAME=value1")
-        assert xspec.env['NAME'] == "value1"
+        assert xspec.env["NAME"] == "value1"
 
     def test__samefilesystem(self):
         assert XSpec("popen")._samefilesystem()
@@ -91,12 +98,12 @@ class TestXSpec:
             assert XSpec(x)._spec == x
 
     def test_samekeyword_twice_raises(self):
-        pytest.raises(ValueError, XSpec, 'popen//popen')
-        pytest.raises(ValueError, XSpec, 'popen//popen=123')
+        pytest.raises(ValueError, XSpec, "popen//popen")
+        pytest.raises(ValueError, XSpec, "popen//popen=123")
 
     def test_unknown_keys_allowed(self):
         xspec = XSpec("hello=3")
-        assert xspec.hello == '3'
+        assert xspec.hello == "3"
 
     def test_repr_and_string(self):
         for x in ("popen", "popen//python=this"):
@@ -112,7 +119,7 @@ class TestXSpec:
 
 class TestMakegateway:
     def test_no_type(self, makegateway):
-        pytest.raises(ValueError, lambda: makegateway('hello'))
+        pytest.raises(ValueError, lambda: makegateway("hello"))
 
     @skip_win_pypy
     def test_popen_default(self, makegateway):
@@ -125,15 +132,18 @@ class TestMakegateway:
         assert rinfo.version_info == sys.version_info
 
     @pytest.mark.skipif("not hasattr(os, 'nice')")
+    @pytest.mark.xfail(reason="fails due to timing problems on busy single-core VMs")
     def test_popen_nice(self, makegateway):
         gw = makegateway("popen")
 
         def getnice(channel):
             import os
-            if hasattr(os, 'nice'):
+
+            if hasattr(os, "nice"):
                 channel.send(os.nice(0))
             else:
                 channel.send(None)
+
         remotenice = gw.remote_exec(getnice).receive()
         gw.exit()
         if remotenice is not None:
@@ -143,10 +153,12 @@ class TestMakegateway:
 
     def test_popen_env(self, makegateway):
         gw = makegateway("popen//env:NAME123=123")
-        ch = gw.remote_exec("""
+        ch = gw.remote_exec(
+            """
             import os
             channel.send(os.environ['NAME123'])
-        """)
+        """
+        )
         value = ch.receive()
         assert value == "123"
 
@@ -177,7 +189,7 @@ class TestMakegateway:
         sshhost = specssh.ssh
         gw = makegateway("ssh=%s//id=ssh1" % sshhost)
         rinfo = gw._rinfo()
-        assert gw.id == 'ssh1'
+        assert gw.id == "ssh1"
         gw2 = execnet.SshGateway(sshhost)
         rinfo2 = gw2._rinfo()
         assert rinfo.executable == rinfo2.executable
@@ -186,16 +198,16 @@ class TestMakegateway:
 
     @pytest.mark.xfail(reason="bad image name", run=False)
     def test_vagrant(self, makegateway, tmpdir, monkeypatch):
-        vagrant = py.path.local.sysfind('vagrant')
+        vagrant = py.path.local.sysfind("vagrant")
         if vagrant is None:
-            pytest.skip('Vagrant binary not in PATH')
+            pytest.skip("Vagrant binary not in PATH")
         monkeypatch.chdir(tmpdir)
         subprocess.check_call("vagrant init hashicorp/precise32", shell=True)
         subprocess.check_call("vagrant up --provider virtualbox", shell=True)
         gw = makegateway("vagrant_ssh=default")
         rinfo = gw._rinfo()
-        rinfo.cwd == '/home/vagrant'
-        rinfo.executable == '/usr/bin/python'
+        rinfo.cwd == "/home/vagrant"
+        rinfo.executable == "/usr/bin/python"
         subprocess.check_call("vagrant halt", shell=True)
 
     def test_socket(self, specsocket, makegateway):
@@ -207,7 +219,7 @@ class TestMakegateway:
         assert gw.id == "sock1"
         # we cannot instantiate a second gateway
 
-    @pytest.mark.xfail(reason='we can\'t instantiate a second gateway')
+    @pytest.mark.xfail(reason="we can't instantiate a second gateway")
     def test_socket_second(self, specsocket, makegateway):
         gw = makegateway("socket=%s//id=sock1" % specsocket.socket)
         gw2 = makegateway("socket=%s//id=sock1" % specsocket.socket)
